@@ -7,6 +7,8 @@ from rez.packages import iter_package_families, iter_packages, get_package, \
 from rez.package_py_utils import expand_requirement
 from rez.package_resources import package_release_keys
 from rez.package_move import move_package
+from rez.package_remove import remove_package, remove_packages_ignored_since
+from rez.package_repository import package_repository_manager
 from rez.tests.util import TestBase, TempdirMixin
 from rez.utils.formatting import PackageRequest
 from rez.utils.sourcecode import SourceCode
@@ -452,10 +454,18 @@ class TestPackages(TestBase, TempdirMixin):
 
         repo = pkg.repository
 
+        # ignore a pkg that doesn't exist
+        i = repo.ignore_package("i_dont_exist", Version("1"))
+        self.assertEqual(i, -1)
+
         # ignore a pkg that doesn't exist, but allow it
         i = repo.ignore_package("i_dont_exist", Version("1"), allow_missing=True)
         self.assertEqual(i, 1)
 
+        # unignore a pkg that doesn't exist
+        i = repo.unignore_package("i_dont_exist", Version("1"))
+        self.assertEqual(i, -1)
+
         # ignore an existing package
         i = repo.ignore_package(pkg_name, pkg_version)
         self.assertEqual(i, 1)
@@ -508,6 +518,53 @@ class TestPackages(TestBase, TempdirMixin):
         src_pkg = get_package_from_repository(pkg_name, pkg_version, repo_path)
         self.assertEqual(src_pkg, None)
 
+    def test_package_remove(self):
+        """Test package remove."""
+        pkg_name = "pydad"
+        pkg_version = Version("2")
+
+        # copy packages to a temp repo
+        repo_path = os.path.join(self.root, "tmp4_packages")
+        shutil.copytree(self.solver_packages_path, repo_path)
+
+        # verify that source pkg exists
+        src_pkg = get_package_from_repository(pkg_name, pkg_version, repo_path)
+        self.assertNotEqual(src_pkg, None)
+
+        # remove it
+        was_removed = remove_package(pkg_name, pkg_version, repo_path)
+        self.assertTrue(was_removed)
+
+        # verify that source pkg no longer exists (and isn't simply ignored)
+        repo = package_repository_manager.get_repository(repo_path)
+        i = repo.unignore_package(pkg_name, pkg_version)
+        self.assertEqual(i, -1)
+
+    def test_remove_packages_ignored_since(self):
+        pkg_name = "pydad"
+        pkg_version = Version("2")
+
+        # copy packages to a temp repo
+        repo_path = os.path.join(self.root, "tmp5_packages")
+        shutil.copytree(self.solver_packages_path, repo_path)
+
+        # verify that source pkg exists
+        src_pkg = get_package_from_repository(pkg_name, pkg_version, repo_path)
+        self.assertNotEqual(src_pkg, None)
+
+        # ignore it
+        repo = package_repository_manager.get_repository(repo_path)
+        i = repo.ignore_package(pkg_name, pkg_version)
+        self.assertEqual(i, 1)
+
+        # remove all ignored packages
+        num_removed = remove_packages_ignored_since(days=0, paths=[repo_path])
+        self.assertEqual(num_removed, 1)
+
+        # verify that source pkg no longer exists (and isn't simply ignored)
+        i = repo.unignore_package(pkg_name, pkg_version)
+        self.assertEqual(i, -1)
+
 
 class TestMemoryPackages(TestBase):
     def test_1_memory_variant_parent(self):
